..
   This is an autogenerated file from processors.rst

avatars.processors.PerturbationProcessor
========================================

.. autoclass:: avatars.processors.PerturbationProcessor
   :members: